<?php
/**
 * About Section
 *
 * @package EnterpriseUp
 */

$wp_customize->add_section(
	'enterpriseup_about_section',
	array(
		'panel'		=> 'enterpriseup_front_page_options',
		'title'		=> esc_html__( 'About Section', 'enterpriseup' ),
		'priority'	=> 30,
	)
);

// About Section - Enable Section.
$wp_customize->add_setting(
	'enterpriseup_enable_about_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'enterpriseup_enable_about_section',
		array(
			'label'    => esc_html__( 'Enable About Section', 'enterpriseup' ),
			'section'  => 'enterpriseup_about_section',
			'settings' => 'enterpriseup_enable_about_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'enterpriseup_enable_about_section',
		array(
			'selector' => '#enterpriseup_about_section .section-link',
			'settings' => 'enterpriseup_enable_about_section',
		)
	);
}

// About Section - Content Type.
$wp_customize->add_setting(
	'enterpriseup_about_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'enterpriseup_sanitize_select',
	)
);

$wp_customize->add_control(
	'enterpriseup_about_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'enterpriseup' ),
		'section'         => 'enterpriseup_about_section',
		'settings'        => 'enterpriseup_about_content_type',
		'type'            => 'select',
		'active_callback' => 'enterpriseup_is_about_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'enterpriseup' ),
			'post' => esc_html__( 'Post', 'enterpriseup' ),
		),
	)
);

// About Section - Content Type Post.
$wp_customize->add_setting(
	'enterpriseup_about_content_post',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'enterpriseup_about_content_post',
	array(
		'section'         => 'enterpriseup_about_section',
		'settings'        => 'enterpriseup_about_content_post',
		'label'           => esc_html__( 'Select Post', 'enterpriseup' ),
		'active_callback' => 'enterpriseup_is_about_section_and_content_type_post_enabled',
		'type'            => 'select',
		'choices'         => enterpriseup_get_post_choices(),
	)
);

// About Section - Content Type Page.
$wp_customize->add_setting(
	'enterpriseup_about_content_page',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'enterpriseup_about_content_page',
	array(
		'label'           => esc_html__( 'Select Page', 'enterpriseup' ),
		'section'         => 'enterpriseup_about_section',
		'settings'        => 'enterpriseup_about_content_page',
		'active_callback' => 'enterpriseup_is_about_section_and_content_type_page_enabled',
		'type'            => 'select',
		'choices'         => enterpriseup_get_page_choices(),
	)
);

// About Section - Button Label.
$wp_customize->add_setting(
	'enterpriseup_about_button_label',
	array(
		'default'           => __( 'About Us', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_about_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'enterpriseup' ),
		'section'         => 'enterpriseup_about_section',
		'settings'        => 'enterpriseup_about_button_label',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_about_section_enabled',
	)
);
