<?php
/**
 * Gallery Section
 *
 * @package EnterpriseUp
 */

$wp_customize->add_section(
	'enterpriseup_gallery_section',
	array(
		'panel'    => 'enterpriseup_front_page_options',
		'title'    => esc_html__( 'Gallery Section', 'enterpriseup' ),
		'priority' => 50,
	)
);

// Gallery Section - Enable Section.
$wp_customize->add_setting(
	'enterpriseup_enable_gallery_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'enterpriseup_enable_gallery_section',
		array(
			'label'    => esc_html__( 'Enable Gallery Section', 'enterpriseup' ),
			'section'  => 'enterpriseup_gallery_section',
			'settings' => 'enterpriseup_enable_gallery_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'enterpriseup_enable_gallery_section',
		array(
			'selector' => '#enterpriseup_gallery_section .section-link',
			'settings' => 'enterpriseup_enable_gallery_section',
		)
	);
}

// Gallery Section - Section Title.
$wp_customize->add_setting(
	'enterpriseup_gallery_title',
	array(
		'default'           => __( 'Our Gallery', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_gallery_title',
	array(
		'label'           => esc_html__( 'Section Title', 'enterpriseup' ),
		'section'         => 'enterpriseup_gallery_section',
		'settings'        => 'enterpriseup_gallery_title',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_gallery_section_enabled',
	)
);

// Gallery Section - Section Text.
$wp_customize->add_setting(
	'enterpriseup_gallery_text',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_gallery_text',
	array(
		'label'           => esc_html__( 'Section Text', 'enterpriseup' ),
		'section'         => 'enterpriseup_gallery_section',
		'settings'        => 'enterpriseup_gallery_text',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_gallery_section_enabled',
	)
);

// Gallery Section - Number of Posts.
$wp_customize->add_setting(
	'enterpriseup_gallery_count',
	array(
		'default'           => 6,
		'sanitize_callback' => 'enterpriseup_sanitize_number_range',
	)
);

$wp_customize->add_control(
	'enterpriseup_gallery_count',
	array(
		'label'           => esc_html__( 'Number of Posts to Show', 'enterpriseup' ),
		'description'     => esc_html__( 'Note: Min 1 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'enterpriseup' ),
		'section'         => 'enterpriseup_gallery_section',
		'settings'        => 'enterpriseup_gallery_count',
		'type'            => 'number',
		'input_attrs'     => array(
			'min' => 1,
			'max' => 6,
		),
		'active_callback' => 'enterpriseup_is_gallery_section_enabled',
	)
);

// Gallery Section - Content Type.
$wp_customize->add_setting(
	'enterpriseup_gallery_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'enterpriseup_sanitize_select',
	)
);

$wp_customize->add_control(
	'enterpriseup_gallery_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'enterpriseup' ),
		'section'         => 'enterpriseup_gallery_section',
		'settings'        => 'enterpriseup_gallery_content_type',
		'type'            => 'select',
		'active_callback' => 'enterpriseup_is_gallery_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'enterpriseup' ),
			'post' => esc_html__( 'Post', 'enterpriseup' ),
		),
	)
);

// List out selected number of fields.
$gallery_count = get_theme_mod( 'enterpriseup_gallery_count', 6 );

for ( $i = 1; $i <= $gallery_count; $i++ ) {
	// Gallery Section - Select Post.
	$wp_customize->add_setting(
		'enterpriseup_gallery_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_gallery_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_gallery_section',
			'settings'        => 'enterpriseup_gallery_content_post_' . $i,
			'active_callback' => 'enterpriseup_is_gallery_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_post_choices(),
		)
	);

	// Gallery Section - Select Page.
	$wp_customize->add_setting(
		'enterpriseup_gallery_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_gallery_content_page_' . $i,
		array(
			'label'           => esc_html__( 'Select Page ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_gallery_section',
			'settings'        => 'enterpriseup_gallery_content_page_' . $i,
			'active_callback' => 'enterpriseup_is_gallery_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_page_choices(),
		)
	);

}

// Gallery Section - Button Label.
$wp_customize->add_setting(
	'enterpriseup_gallery_button_label',
	array(
		'default'           => __( 'View All', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_gallery_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'enterpriseup' ),
		'section'         => 'enterpriseup_gallery_section',
		'settings'        => 'enterpriseup_gallery_button_label',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_gallery_section_enabled',
	)
);

// Gallery Section - Button Link.
$wp_customize->add_setting(
	'enterpriseup_gallery_button_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'enterpriseup_gallery_button_link',
	array(
		'label'           => esc_html__( 'Button Link', 'enterpriseup' ),
		'section'         => 'enterpriseup_gallery_section',
		'settings'        => 'enterpriseup_gallery_button_link',
		'type'            => 'url',
		'active_callback' => 'enterpriseup_is_gallery_section_enabled',
	)
);
