<?php

if ( ! get_theme_mod( 'enterpriseup_enable_features_section', false ) ) {
	return;
}

$content_ids  = array();
$content_type = get_theme_mod( 'enterpriseup_features_content_type', 'page' );

if ( in_array( $content_type, array( 'post', 'page' ) ) ) {

	for ( $i = 1; $i <= 4; $i++ ) {
		$content_ids[] = get_theme_mod( 'enterpriseup_features_content_' . $content_type . '_' . $i );
	}

	$args = array(
		'post_type'           => $content_type,
		'post__in'            => array_filter( $content_ids ),
		'orderby'             => 'post__in',
		'posts_per_page'      => absint( 4 ),
		'ignore_sticky_posts' => true,
	);

}

$args = apply_filters( 'enterpriseup_features_section_args', $args );

enterpriseup_render_features_section( $args );

/**
 * Render Features Section.
 */
function enterpriseup_render_features_section( $args ) {
	$section_title = get_theme_mod( 'enterpriseup_features_title', 'Our Features' );
	$section_text  = get_theme_mod( 'enterpriseup_features_text' );
	$section_image = get_theme_mod( 'enterpriseup_features_image' );

	$query = new WP_Query( $args );
	if ( $query->have_posts() ) :
		?>
		<section id="enterpriseup_features_section" class="enterpriseup-frontpage-section enterpriseup-features-section enterpriseup-secondary1-background">
			<?php
			if ( is_customize_preview() ) :
				enterpriseup_section_link( 'enterpriseup_features_section' );
			endif;
			?>
			<div class="features-section-img">
				<img src="<?php echo esc_url( $section_image ); ?>" alt="<?php echo esc_attr( $section_title ); ?>">
			</div>
			<div class="ascendoor-wrapper">
				<div class="enterpriseup-features-section-inside">
					<?php if ( ! empty( $section_title || $section_text ) ) { ?>
						<div class="section-header-subtitle">
							<h3 class="section-title"><?php echo esc_html( $section_title ); ?></h3>
							<p class="section-subtitle"><?php echo esc_html( $section_text ); ?></p>
						</div>
					<?php } ?>
					<div class="enterpriseup-section-body">
						<div class="enterpriseup-features-section-wrapper">
							<?php
							while ( $query->have_posts() ) :
								$query->the_post();
								?>
								<div class="enterpriseup-features-single">
									<div class="features-icon">
										<?php the_post_thumbnail(); ?>
									</div>
									<div class="features-details">
									<h3 class="feature-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
										<p class="feature-details">
											<?php the_excerpt(); ?>
										</p>
									</div>
								</div>
								<?php
							endwhile;
							wp_reset_postdata();
							?>
						</div>
					</div>
				</div>
			</div>
		</section>
		<?php
	endif;
}
